.. _acrobot:

Acrobot with Euler Integration
------------------------------

.. autoclass:: rlpy.Domains.Acrobot.AcrobotLegacy
    :members:
    :inherited-members:

Acrobot with Runge-Kutta Integration
------------------------------------

.. autoclass:: rlpy.Domains.Acrobot.Acrobot
    :members:
